@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "ellama" "20260216.307"
+(define-package "ellama" "20260216.2316"
   "Tool for interacting with LLMs."
   '((emacs     "28.1")
     (llm       "0.24.0")
@@ -7,9 +7,9 @@
     (transient "0.7")
     (compat    "29.1")
     (yaml      "1.2.3"))
-  :url "http://github.com/s-kostyaev/ellama"
-  :commit "b32479ffc3c52a1d5ecbf8192869a86a679ac184"
-  :revdesc "b32479ffc3c5"
+  :url "https://github.com/s-kostyaev/ellama"
+  :commit "500544fe539fc7120efd144030fc5469a6d880c7"
+  :revdesc "500544fe539f"
   :keywords '("help" "local" "tools")
   :authors '(("Sergey Kostyaev" . "sskostyaev@gmail.com"))
   :maintainers '(("Sergey Kostyaev" . "sskostyaev@gmail.com")))
